@@ -7,7 +7,6 @@ import threading
 from datetime import datetime
 from func_timeout import func_set_timeout
 from func_timeout.exceptions import FunctionTimedOut
-from paramiko import SSHException
 import time
 import functools
 import logging
@@ -94,7 +93,7 @@ class SSHClient(object):
             )
             log.info(f"{self.__ip}:{self.__port} | create ssh session successfully.")
             return True
-        except SSHException as e:
+        except paramiko.ssh_exception.SSHException as e:
             log.warning(f"{self.__ip}:{self.__port} | cannot create ssh session, err msg is {str(e)}.")
             return False
         except Exception as e:
@@ -138,9 +137,8 @@ class SSHClient(object):
         except socket.timeout as e:
             log.warning(f"{self.__ip}:{self.__port} | failed to ssh connect. server may not be sshable, please try again later...")
             return False
-        except SSHException as e:
+        except paramiko.ssh_exception.SSHException as e:
             log.warning(f"{self.__ip}:{self.__port} | failed to ssh connect. server may not be sshable, please try again later...")
-            return False
         except Exception as e:
             log.warning(f"{self.__ip}:{self.__port} | failed to ssh connect. err msg is {str(e)}")
             return False
@@ -404,7 +402,7 @@ class SSHClient(object):
             self.__sftp.getcwd()
             log.info(f" {self.__ip}:{self.__port} | SFTP连接已激活")
             return True
-        except (paramiko.SSHException, IOError, OSError,Exception) as e:
+        except (paramiko.ssh_exception.SSHException, IOError, OSError,Exception) as e:
             log.warning(f" {self.__ip}:{self.__port} | SFTP连接异常: {str(e)}")
             return False
 
